# -*- coding: utf-8 -*-
"""
Tests the utilities for the Video Abstraction Layer
"""
from django.core.files.base import ContentFile
from django.test import TestCase

from edxval.utils import generate_file_content_hash, is_duplicate_file


class UtilityTests(TestCase):
    """
    Tests utility methods
    """
    def test_generate_file_content_hash(self):
        """
        Tests generating file content hash and makes sure the hash returned is
        64 characters long
        """
        file_data = ContentFile('Greetings')

        content_hash = generate_file_content_hash(file_data)

        self.assertEqual(len(content_hash), 64)

    def test_same_content_is_duplicate_file(self):
        """
        Tests the `is_duplicate_file` by generating a hash for a content file
        and then passing the hash and the content to the method to make sure
        that the 'files' are the same/duplicates.
        """
        file_content = 'Greetings'

        file_data = ContentFile(file_content)
        other_file_data = ContentFile(file_content)

        self.assertTrue(is_duplicate_file(file_data, other_file_data))

    def test_different_content_is_duplicate_file(self):
        """
        Tests the `is_duplicate_file` by generating a hash for a content file
        and then passing the hash and the different file content to the method
        to make sure that the 'files' are the different.
        """
        file_content = 'Greetings'
        other_file_content = 'Hello there'

        file_data = ContentFile(file_content)
        other_file_data = ContentFile(other_file_content)

        self.assertFalse(is_duplicate_file(file_data, other_file_data))



"""
This module contains various configuration settings via
waffle switches for edx's video abstraction layer.
"""


from edx_toggles.toggles import WaffleFlag

WAFFLE_NAMESPACE = 'edxval'

# .. toggle_name: edxval.override_existing_imported_transcripts
# .. toggle_implementation: WaffleFlag
# .. toggle_default: False
# .. toggle_description: Enables overriding existing transcripts when importing courses with already
#   existing transcripts. The transcripts are compared using content hashing, and if the transcript
#   being imported isn't a duplicate, but different in content, it overrides the existing one.
#   Otherwise, if the transcript is a duplicate, with same content, it doesn't get uploaded.
# .. toggle_use_cases: opt_in
# .. toggle_creation_date: 2021-01-01
# .. toggle_tickets: https://openedx.atlassian.net/browse/OSPR-5117
OVERRIDE_EXISTING_IMPORTED_TRANSCRIPTS = WaffleFlag(
    f'{WAFFLE_NAMESPACE}.override_existing_imported_transcripts', __name__
)



"""
Url file for django app edxval.
"""
from django.conf import settings
from django.urls import path, re_path

from edxval import views

urlpatterns = [
    path('videos/', views.VideoList.as_view(), name='video-list'),
    re_path(
        r'^videos/(?P<edx_video_id>[-\w]+)$',
        views.VideoDetail.as_view(),
        name='video-detail'
    ),
    path('videos/status/', views.VideoStatusView.as_view(),
         name='video-status-update'
         ),
    path('videos/missing-hls/', views.HLSMissingVideoView.as_view(),
         name='hls-missing-video'
         ),
    path('videos/course-transcripts/<str:course_id>/', views.CourseTranscriptsDetailView.as_view(),
         name='course-transcripts'
         ),
    path('videos/video-transcripts/create/', views.VideoTranscriptView.as_view(),
         name='create-video-transcript'
         ),
    path('videos/video-transcripts/', views.VideoTranscriptView.as_view(),
         name='video-transcripts'
         ),
    path('videos/video-images/update/', views.VideoImagesView.as_view(),
         name='update-video-images'
         ),
    path('videos/courses/<str:course_id>/video-ids', views.CourseVideoIDsView.as_view(),
         name='course-video-ids'
         ),
]

if getattr(settings, 'PROVIDER_STATES_SETUP_VIEW_URL', None):
    from edxval.pacts.views import provider_state
    urlpatterns.append(re_path(
        r'^pact/provider_states/$',
        provider_state,
        name='provider-state-view'
    ))



# Generated by Django 2.2.12 on 2020-04-29 05:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('edxval', '0001_squashed_0016_add_transcript_credentials_model'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='error_description',
            field=models.TextField(blank=True, null=True, verbose_name='Error Description'),
        ),
    ]



#!/usr/bin/env python


import os
import re
import sys

from setuptools import setup

PACKAGES = [
    'edxval',
    'edxval.config',
    'edxval.migrations',
    'edxval.tests',
]


def is_requirement(line):
    """
    Return True if the requirement line is a package requirement;
    that is, it is not blank, a comment, or editable.
    """
    # Remove whitespace at the start/end of the line
    line = line.strip()

    # Skip blank lines, comments, and editable installs
    return not (
        line == '' or
        line.startswith('-r') or
        line.startswith('#') or
        line.startswith('-e') or
        line.startswith('git+') or
        line.startswith('-c')
    )


def load_requirements(*requirements_paths):
    """
    Load all requirements from the specified requirements files.
    Returns a list of requirement strings.
    """
    requirements = set()
    for path in requirements_paths:
        requirements.update(
            line.split('#')[0].strip() for line in open(path).readlines()
            if is_requirement(line)
        )
    return list(requirements)


def get_version(*file_paths):
    """
    Extract the version string from the file at the given relative path fragments.
    """
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    with open(filename, encoding='utf-8') as opened_file:
        version_file = opened_file.read()
        version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                                  version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


VERSION = get_version("edxval", "__init__.py")

if sys.argv[-1] == 'tag':
    print("Tagging the version on github:")
    os.system("git tag -a v%s -m 'version %s'" % (VERSION, VERSION))
    os.system("git push --tags")
    sys.exit()

setup(
    name='edxval',
    version=VERSION,
    author='edX',
    url='http://github.com/openedx/edx-val',
    description='edx-val',
    long_description='edx-val',
    long_description_content_type='text/x-rst',
    license='AGPL',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Affero General Public License v3',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.11',
        'Framework :: Django',
        'Framework :: Django :: 4.2',
    ],
    packages=PACKAGES,
    install_requires=load_requirements('requirements/base.in'),
    tests_require=load_requirements('requirements/test.in'),
)
